==> apache-druid-0.22.0-src.tar.gz: apache-druid-0.22.0-src/indexing-service/src/main/java/org/apache/druid/indexing/common/TaskLock.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.indexing.common;

import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonSubTypes.Type;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeInfo.Id;
import org.apache.druid.indexing.overlord.LockRequest;
import org.joda.time.Interval;

import javax.annotation.Nullable;

/**
 * Represents a lock held by some task. Immutable.
 */
@JsonTypeInfo(use = Id.NAME, property = "granularity", defaultImpl = TimeChunkLock.class)
@JsonSubTypes(value = {
    @Type(name = TimeChunkLock.TYPE, value = TimeChunkLock.class),
    @Type(name = SegmentLock.TYPE, value = SegmentLock.class)
})
public interface TaskLock
{
  TaskLock revokedCopy();

  TaskLock withPriority(int priority);

  LockGranularity getGranularity();

  TaskLockType getType();

  String getGroupId();

  String getDataSource();

  Interval getInterval();

  String getVersion();

  @Nullable
  Integer getPriority();

  int getNonNullPriority();

  boolean isRevoked();

  boolean conflict(LockRequest request);
}

==> apache-druid-35.0.1-src.tar.gz: apache-druid-35.0.1-src/indexing-service/src/main/java/org/apache/druid/indexing/common/TaskLock.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.indexing.common;

import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonSubTypes.Type;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeInfo.Id;
import org.apache.druid.error.DruidException;
import org.apache.druid.indexing.overlord.LockRequest;
import org.joda.time.Interval;

import javax.annotation.Nullable;

/**
 * Represents a lock held by some task. Immutable.
 */
@JsonTypeInfo(use = Id.NAME, property = "granularity", defaultImpl = TimeChunkLock.class)
@JsonSubTypes(value = {
    @Type(name = TimeChunkLock.TYPE, value = TimeChunkLock.class),
    @Type(name = SegmentLock.TYPE, value = SegmentLock.class)
})
public interface TaskLock
{
  TaskLock revokedCopy();

  TaskLock withPriority(int priority);

  LockGranularity getGranularity();

  TaskLockType getType();

  String getGroupId();

  String getDataSource();

  Interval getInterval();

  String getVersion();

  @Nullable
  Integer getPriority();

  int getNonNullPriority();

  boolean isRevoked();

  boolean conflict(LockRequest request);

  /**
   * Checks if the lock is revoked and throws a {@link DruidException} if so.
   *
   * @throws DruidException if the lock is revoked.
   */
  default void assertNotRevoked()
  {
    if (isRevoked()) {
      throw DruidException.forPersona(DruidException.Persona.OPERATOR)
          .ofCategory(DruidException.Category.RUNTIME_FAILURE)
          .build("Lock of type[%s] for interval[%s] was revoked", getType(), getInterval());
    }
  }
}
